python-watchhub
================

.. image:: https://travis-ci.com/imduffy15/python-watchhub.svg?branch=master
   :target: https://travis-ci.com/imduffy15/python-watchhub
   :alt: Build Status
.. image:: https://coveralls.io/repos/github/imduffy15/python-watchhub/badge.svg
   :target: https://coveralls.io/github/imduffy15/python-watchhub
   :alt: Coverage Status
.. image:: https://pepy.tech/badge/watchhub
   :target: https://pepy.tech/project/watchhub
   :alt: Downloads

Documentation for this package can be found at `https://watchhub.readthedocs.io <https://watchhub.readthedocs.io>`_.

``watchhub`` is a Python package for querying the strem.io Watchhub API. This API enables you to discover content IDs across many stream services such as netflix, disney+, nowtv, etc. from a IMDB ID


Installation
------------

.. code-block::

   pip install watchhub


To utilize the async version of this code, you must install into a Python 3.7+ environment via:

.. code-block::

   pip install watchhub[async]
